[Rivet-svn] r2215 - trunk/src/Analyses

blackhole at projects.hepforge.org blackhole at projects.hepforge.org
Sun Jan 17 18:16:44 GMT 2010


Author: holsch
Date: Sun Jan 17 18:16:43 2010
New Revision: 2215

Log:
Fix Et cut for electrons.

Modified:
   trunk/src/Analyses/CDF_1991_S2313472.cc

Modified: trunk/src/Analyses/CDF_1991_S2313472.cc
==============================================================================
--- trunk/src/Analyses/CDF_1991_S2313472.cc	Sun Jan 17 18:09:03 2010	(r2214)
+++ trunk/src/Analyses/CDF_1991_S2313472.cc	Sun Jan 17 18:16:43 2010	(r2215)
@@ -55,7 +55,7 @@
         vetoEvent;
       }
 
       // Require the electron to have ET > 12 GeV, pT > 6 GeV and |eta| < 1.1
       FourMomentum p_e;
       int chg_e = 0;
 
@@ -65,7 +65,7 @@
           chg_e = PID::threeCharge(l.pdgId());
           p_e = pl;
           const double eta_e = fabs(p_e.pseudorapidity());
-          if ( (pl.Et()/GeV < 12.0) || (pl.pT()/GeV < 6.0) || (eta_e > 1.1) ) {
+          if ( (pl.Et()/GeV < 20.0) || (pl.pT()/GeV < 6.0) || (eta_e > 1.1) ) {
             getLog() << Log::DEBUG << l.pdgId() << " ET,pT,eta: " << pl.Et()/GeV << "," << pl.pT()/GeV << "," << eta_e << " fails electron cut" << endl;
             vetoEvent;
           }
@@ -55,7 +55,7 @@
       }
 
-      // Require the electron to have ET > 12 GeV, pT > 6 GeV and |eta| < 1.1
+      // Require the electron to have ET > 20 GeV, pT > 6 GeV and |eta| < 1.1
       FourMomentum p_e;
       int chg_e = 0;


More information about the Rivet-svn mailing list